@@ -557,6 +557,8 @@ TSPRegistryMapping = {
     "6379": "TST.CommandRewritePivotOwnerFormulasArchive",
     "6380": "TST.CommandRewriteTrackedReferencesArchive",
     "6381": "TST.CommandExtendTableIDHistoryArchive",
+    "6382": "TST.GroupByArchive.AggregatorArchive",
+    "6383": "TST.GroupByArchive.GroupNodeArchive",
     "10011": "TSWP.SectionPlaceholderArchive",
     "10020": "TSWP.ShapeSelectionTransformerArchive",
     "10021": "TSWP.SelectionTransformerArchive",
@@ -633,10 +635,18 @@ TSPRegistryMapping = {
 
 def compute_maps():
     name_class_map = {}
+
+    def add_nested_types(message_type):
+        for name in message_type.DESCRIPTOR.nested_types_by_name:
+            child_type = getattr(message_type, name)
+            name_class_map[child_type.DESCRIPTOR.full_name] = child_type
+            add_nested_types(child_type)
+
     for file in PROTO_FILES:
         for message_name in file.DESCRIPTOR.message_types_by_name:
             message_type = getattr(file, message_name)
             name_class_map[message_type.DESCRIPTOR.full_name] = message_type
+            add_nested_types(message_type)
 
     id_name_map = {}
     for k, v in list(TSPRegistryMapping.items()):
